==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Block/InsertBlock/ts/InsertBlock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Insert</name>
    <message>
        <source>Position</source>
        <translation type="obsolete">Position</translation>
    </message>
    <message>
        <source>&amp;Insert Block</source>
        <translation type="obsolete">&amp;Insérer bloc</translation>
    </message>
</context>
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+107"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Insérer bloc</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotation :</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Faire pivoter le&lt;br&gt;bloc par cet angle</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>Echelle X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Échelle du bloc en X&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y :</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Échelle du bloc en Y&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Garder les proportions</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Retourner bloc&lt;br&gt;horizontalement</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Retourner bloc&lt;br&gt;verticalement</translation>
    </message>
    <message>
        <source>Attribute 1:</source>
        <translation type="obsolete">Attribute 1:</translation>
    </message>
    <message>
        <source>Attribute 2:</source>
        <translation type="obsolete">Attribute 2:</translation>
    </message>
    <message>
        <source>Attribute 3:</source>
        <translation type="obsolete">Attribute 3:</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">Rotation :</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">Faire pivoter le&lt;br&gt;bloc par cet angle</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">Echelle X:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">Échelle du bloc en X&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">Garder les proportions</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">Echelle Y:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Échelle du bloc en Y&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">Retourner bloc&lt;br&gt;horizontalement</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">Retourner bloc&lt;br&gt;verticalement</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Block/InsertBlock/ts/InsertBlock_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Insert</name>
    <message>
        <source>Position</source>
        <translation type="obsolete">Position</translation>
    </message>
    <message>
        <source>&amp;Insert Block</source>
        <translation type="obsolete">&amp;Insérer bloc</translation>
    </message>
</context>
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+108"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Insérer bloc</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotation :</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Faire pivoter le&lt;br&gt;bloc par cet angle</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>Echelle X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Échelle du bloc en X&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y :</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Échelle du bloc en Y&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Garder les proportions</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Retourner bloc&lt;br&gt;horizontalement</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Retourner bloc&lt;br&gt;verticalement</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Single Block</source>
        <translation>Seul bloc</translation>
    </message>
    <message>
        <location line="+17"/>
        <location filename="../InsertBlockDialog.ui" line="+14"/>
        <source>Array of Blocks</source>
        <translation>Tableau de blocs</translation>
    </message>
    <message>
        <source>Attribute 1:</source>
        <translation type="obsolete">Attribute 1:</translation>
    </message>
    <message>
        <source>Attribute 2:</source>
        <translation type="obsolete">Attribute 2:</translation>
    </message>
    <message>
        <source>Attribute 3:</source>
        <translation type="obsolete">Attribute 3:</translation>
    </message>
    <message>
        <source>Move / Copy Options</source>
        <translation type="obsolete">Options de déplacement/copie</translation>
    </message>
    <message>
        <location filename="../InsertBlockDialog.ui" line="+12"/>
        <source>Columns:</source>
        <translation>Colonnes :</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Rows:</source>
        <translation>Lignes :</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Column Spacing:</source>
        <translation>Espacement des colonnes :</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Row Spacing:</source>
        <translation>Espacement des lignes :</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">Rotation :</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">Faire pivoter le&lt;br&gt;bloc par cet angle</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">Echelle X:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">Échelle du bloc en X&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">Garder les proportions</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">Echelle Y:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Échelle du bloc en Y&lt;br&gt;par ce facteur</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">Retourner bloc&lt;br&gt;horizontalement</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">Retourner bloc&lt;br&gt;verticalement</translation>
    </message>
</context>
</TS>
